@@ -183,7 +183,7 @@ class ImportScanSerializer(Schema):
     auto_create_context = fields.Str(required=False, load_default="true")
     deduplication_on_engagement = fields.Str(required=False)
     lead = fields.Str(required=False)
-    tags = fields.Str(required=True)
+    tags = fields.List(fields.String(), required=True)
     close_old_findings = fields.Str(required=False, load_default=True)
     close_old_findings_product_scope = fields.Str(required=False)
     push_to_jira = fields.Str(required=False)
@@ -224,4 +224,4 @@ class ImportScanSerializer(Schema):
 
     @post_load
     def make_cmdb(self, data, **kwargs):
-        return ImportScanRequest(**data)
+        return ImportScanRequest(**data)
\ No newline at end of file
